.. rst-class:: detail

SetDigital
=====================

.. currentmodule:: compas_rrc

.. autoclass:: SetDigital

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~SetDigital.__init__
        ~SetDigital.from_msg
    
    